@@ -3,9 +3,9 @@
 Example of a telnet application that displays a dialog window.
 """
 import logging
+from asyncio import Future, run
 
 from prompt_toolkit.contrib.telnet.server import TelnetServer
-from prompt_toolkit.eventloop import get_event_loop
 from prompt_toolkit.shortcuts.dialogs import yes_no_dialog
 
 # Set up logging
@@ -22,11 +22,13 @@ async def interact(connection):
     connection.send("Bye.\n")
 
 
-def main():
+async def main():
     server = TelnetServer(interact=interact, port=2323)
     server.start()
-    get_event_loop().run_forever()
+
+    # Run forever.
+    await Future()
 
 
 if __name__ == "__main__":
-    main()
+    run(main())
